==> cuidai_plugin-1.0.6.tar.gz: lib/cuidai_plugin.dart <==
import 'dart:convert';

import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';

class CuidaiRoutes {
  CuidaiRoutes._();
  static const String programDecision = "rd://programs.decision";
  static const String programExplorer = "rd://programs.discover";
  static const String programSearch = "rd://programs.search";
  static const String exerciseExplorer = "rd://trainings.discover";
  static const String meditationExplorer = "rd://meditations.discover";
}

class CuidaiCommunication {
  Function _onRoute;

  CuidaiCommunication({@required onRoute(String route)}){
    _onRoute = onRoute;
  }

  Future<dynamic> nativeMethodCallHandler(MethodCall call) async {
    switch (call.method) {
      case "route" :
        String route = call.arguments["route"];
        _onRoute(route);
        return true;
      default:
        return false;
    }
  }
}

class CuidaiPlugin {
  static const MethodChannel _channelToNative = MethodChannel('cuidai_plugin');
  static const MethodChannel _channelFromNative = MethodChannel('cuidai_plugin_native');

  static void initSDK({Map<String, String> params, CuidaiCommunication communication}) async {
    try {
      if(communication != null){
        _channelFromNative.setMethodCallHandler(communication.nativeMethodCallHandler);
      }
      await _channelToNative.invokeMethod('initSDK', {
        'params': json.encode(params)
      });
    } on PlatformException catch (e) {
      print(e.message);
    }
  }

  static void route({@required String deeplink}) async {
    try {
      await _channelToNative.invokeMethod('route', {
        "route": deeplink,
      });
    } on PlatformException catch (e) {
      print(e.message);
    }
  }

  static void test({@required String route}) async {
    try {
      await _channelToNative.invokeMethod('test', {"route": route});
    } on PlatformException catch (e) {
      print(e.message);
    }
  }
}

==> cuidai_plugin-1.0.7.tar.gz: lib/cuidai_plugin.dart <==
import 'dart:convert';

import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';

class CuidaiRoutes {
  CuidaiRoutes._();
  static const String programDecision = "vitat://programs.decision";
  static const String programExplorer = "vitat://programs.discover";
  static const String programSearch = "vitat://programs.search";
  static const String exerciseExplorer = "vitat://trainings.discover";
  static const String meditationExplorer = "vitat://meditations.discover";
}

class CuidaiCommunication {
  Function _onRoute;

  CuidaiCommunication({@required onRoute(String route)}){
    _onRoute = onRoute;
  }

  Future<dynamic> nativeMethodCallHandler(MethodCall call) async {
    switch (call.method) {
      case "route" :
        String route = call.arguments["route"];
        _onRoute(route);
        return true;
      default:
        return false;
    }
  }
}

class CuidaiPlugin {
  static const MethodChannel _channelToNative = MethodChannel('cuidai_plugin');
  static const MethodChannel _channelFromNative = MethodChannel('cuidai_plugin_native');

  static void initSDK({Map<String, String> params, CuidaiCommunication communication}) async {
    try {
      if(communication != null){
        _channelFromNative.setMethodCallHandler(communication.nativeMethodCallHandler);
      }
      await _channelToNative.invokeMethod('initSDK', {
        'params': json.encode(params)
      });
    } on PlatformException catch (e) {
      print(e.message);
    }
  }

  static void route({@required String deeplink}) async {
    try {
      await _channelToNative.invokeMethod('route', {
        "route": deeplink,
      });
    } on PlatformException catch (e) {
      print(e.message);
    }
  }

  static void test({@required String route}) async {
    try {
      await _channelToNative.invokeMethod('test', {"route": route});
    } on PlatformException catch (e) {
      print(e.message);
    }
  }
}
